@@ -1,3 +1,4 @@
+import django
 from bx_py_utils.test_utils.snapshot import assert_text_snapshot
 
 from manage_django_project.tests.cmd2_test_utils import BaseShellTestCase
@@ -13,4 +14,4 @@ class ManageDjangoShellTestCase(BaseShellTestCase):
         self.assertIn('makemigrations', stdout)
         self.assertIn('manage_django_project', stdout)
         self.assertIn('run_dev_server', stdout)
-        assert_text_snapshot(got=stdout)
+        assert_text_snapshot(got=stdout, snapshot_name=f'test_command_shell_help_django{django.__version__}')
