@@ -2,7 +2,7 @@ from types import ModuleType
 
 from django.core.management import call_command
 from django.test import SimpleTestCase
-from manageprojects.test_utils.project_setup import check_editor_config
+from manageprojects.test_utils.project_setup import check_editor_config, get_py_max_line_length
 from packaging.version import Version
 
 from manage_django_project import __version__
@@ -26,9 +26,6 @@ class ProjectSettingsTestCase(SimpleTestCase):
         version = Version(__version__)
         self.assertEqual(project_info.module_version, version)
 
-    def test_check_editor_config(self):
-        check_editor_config(package_root=project_info.config.project_root_path)
-
     def test_code_style(self):
         # Just run our django manage command that call's darker and flake8
 
@@ -37,3 +34,9 @@ class ProjectSettingsTestCase(SimpleTestCase):
         except SystemExit as err:
             if err.code != 0:
                 self.fail('Code style errors, see above!')
+
+    def test_check_editor_config(self):
+        check_editor_config(package_root=project_info.config.project_root_path)
+
+        max_line_length = get_py_max_line_length(package_root=project_info.config.project_root_path)
+        self.assertEqual(max_line_length, 119)
